==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkUndirectedGraph.java <==
// java wrapper for vtkUndirectedGraph object
//

package vtk;
import vtk.*;

public class vtkUndirectedGraph extends vtkGraph
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataObjectType_2();
  public int GetDataObjectType()
    { return GetDataObjectType_2(); }

  private native int GetInDegree_3(int id0);
  public int GetInDegree(int id0)
    { return GetInDegree_3(id0); }

  private native void GetInEdge_4(int id0,int id1,vtkGraphEdge id2);
  public void GetInEdge(int id0,int id1,vtkGraphEdge id2)
    { GetInEdge_4(id0,id1,id2); }

  private native long GetData_5(vtkInformation id0);
  public vtkUndirectedGraph GetData(vtkInformation id0) {
    long temp = GetData_5(id0);

    if (temp == 0) return null;
    return (vtkUndirectedGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_6(vtkInformationVector id0,int id1);
  public vtkUndirectedGraph GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_6(id0,id1);

    if (temp == 0) return null;
    return (vtkUndirectedGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetInEdges_7(int id0,vtkInEdgeIterator id1);
  public void GetInEdges(int id0,vtkInEdgeIterator id1)
    { GetInEdges_7(id0,id1); }

  private native boolean IsStructureValid_8(vtkGraph id0);
  public boolean IsStructureValid(vtkGraph id0)
    { return IsStructureValid_8(id0); }

  public vtkUndirectedGraph() { super(); }

  public vtkUndirectedGraph(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-armv7h.pkg.tar.xz: vtk/vtkUndirectedGraph.java <==
// java wrapper for vtkUndirectedGraph object
//

package vtk;
import vtk.*;

public class vtkUndirectedGraph extends vtkGraph
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataObjectType_2();
  public int GetDataObjectType()
    { return GetDataObjectType_2(); }

  private native int GetInDegree_3(int id0);
  public int GetInDegree(int id0)
    { return GetInDegree_3(id0); }

  private native void GetInEdge_4(int id0,int id1,vtkGraphEdge id2);
  public void GetInEdge(int id0,int id1,vtkGraphEdge id2)
    { GetInEdge_4(id0,id1,id2); }

  private native long GetData_5(vtkInformation id0);
  public vtkUndirectedGraph GetData(vtkInformation id0) {
    long temp = GetData_5(id0);

    if (temp == 0) return null;
    return (vtkUndirectedGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_6(vtkInformationVector id0,int id1);
  public vtkUndirectedGraph GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_6(id0,id1);

    if (temp == 0) return null;
    return (vtkUndirectedGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetInEdges_7(int id0,vtkInEdgeIterator id1);
  public void GetInEdges(int id0,vtkInEdgeIterator id1)
    { GetInEdges_7(id0,id1); }

  private native boolean IsStructureValid_8(vtkGraph id0);
  public boolean IsStructureValid(vtkGraph id0)
    { return IsStructureValid_8(id0); }

  public vtkUndirectedGraph() { super(); }

  public vtkUndirectedGraph(long id) { super(id); }
  public native long   VTKInit();

}
